ananke.identification
=====================

..
   Submodules
   ----------

ananke.identification.missing\_id
---------------------------------

.. automodule:: ananke.identification.missing_id
   :members:
   :undoc-members:
   :show-inheritance:

ananke.identification.one\_line
-------------------------------

.. automodule:: ananke.identification.one_line
   :members:
   :undoc-members:
   :show-inheritance:

ananke.identification.opt\_adjust
---------------------------------

.. automodule:: ananke.identification.opt_adjust
   :members:
   :undoc-members:
   :show-inheritance:

ananke.identification.oracle
----------------------------

.. automodule:: ananke.identification.oracle
   :members:
   :undoc-members:
   :show-inheritance:

..
   Module contents
   ---------------

.. automodule:: ananke.identification
   :members:
   :undoc-members:
   :show-inheritance:
